@@ -1,5 +1,5 @@
 import unittest
-from libraries.python3.minio_handler.minio_handler.minio_handler import Minio_Handler
+from minio_handler import Minio_Handler
 import os
 import time
 
@@ -17,6 +17,10 @@ class TestHandler(unittest.TestCase):
     object_store.bucket("test-object", "create")
     object_store.object("test-object", "get_test.txt", "put", bytes("test data", encoding='utf-8'))
     object_store.object("test-object", "delete_test.txt", "put", bytes("test data", encoding='utf-8'))
+    data = object_store.object("test-object", "none", "list")
+    print(data)
+    for item in data:
+        print(item)
 
     def test_bucket_create(self):
         self.assertTrue(
@@ -54,6 +58,12 @@ class TestHandler(unittest.TestCase):
             "Object get test"
         )
 
+    def test_object_list(self):
+        self.assertTrue(
+            isinstance(self.object_store.object("test-object", "none", "list"), list),
+            "Object get test"
+        )
+
 
 if __name__ == '__main__':
     try:
